@@ -10,8 +10,9 @@ use Path::Tiny;
 use JSON::MaybeXS 'decode_json';
 with 'Badge::Depot';
 
-our $VERSION = '0.0202'; # VERSION
 # ABSTRACT: Travis plugin for Badge::Depot
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0203';
 
 has user => (
     is => 'ro',
@@ -50,15 +51,15 @@ has _meta => (
 sub _build_meta {
     my $self = shift;
 
-    return if !path('META.json')->exists;
+    return {} if !path('META.json')->exists;
 
     my $json = path('META.json')->slurp_utf8;
     my $data = decode_json($json);
 
-    return if !exists $data->{'resources'}{'repository'}{'web'};
+    return {} if !exists $data->{'resources'}{'repository'}{'web'};
 
     my $repository = $data->{'resources'}{'repository'}{'web'};
-    return if $repository !~ m{^https://(?:www\.)?github\.com/([^/]+)/(.*)(?:\.git)?$};
+    return {} if $repository !~ m{^https://(?:www\.)?github\.com/([^/]+)/(.*)(?:\.git)?$};
 
     return {
         username => $1,
@@ -85,9 +86,23 @@ __END__
 
 Badge::Depot::Plugin::Travis - Travis plugin for Badge::Depot
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Badge-Depot-Plugin-Travis"><img src="https://api.travis-ci.org/Csson/p5-Badge-Depot-Plugin-Travis.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Badge-Depot-Plugin-Travis-0.0203"><img src="https://badgedepot.code301.com/badge/kwalitee/Badge-Depot-Plugin-Travis/0.0203" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Badge-Depot-Plugin-Travis%200.0203"><img src="https://badgedepot.code301.com/badge/cpantesters/Badge-Depot-Plugin-Travis/0.0203" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-67.3%-red.svg" alt="coverage 67.3%" />
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.0202, released 2015-03-22.
+Version 0.0203, released 2016-04-09.
 
 =head1 SYNOPSIS
 
@@ -156,7 +171,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
